@@ -1,5 +1,3 @@
-import datetime
-import os
 import shlex
 
 from ocp_utilities.logger import get_logger
@@ -9,30 +7,6 @@ from ocp_utilities.utils import run_command
 LOGGER = get_logger(name=__name__)
 
 
-def must_gather_command(
-    dest_dir=None,
-    image_url=None,
-    skip_tls_check=False,
-    kubeconfig=None,
-    script_name=None,
-):
-    base_command = "oc adm must-gather"
-    if dest_dir:
-        base_command += f" --dest-dir={dest_dir}"
-    if image_url:
-        base_command += f" --image={image_url}"
-    if skip_tls_check:
-        base_command += " --insecure-skip-tls-verify"
-    if kubeconfig:
-        base_command += f" --kubeconfig {kubeconfig}"
-    # script_name must be the last argument
-    if script_name:
-        base_command += f" -- {script_name}"
-
-    LOGGER.info(f"must-gather command: {base_command}")
-    return base_command
-
-
 def run_must_gather(
     image_url=None,
     target_base_dir=None,
@@ -54,22 +28,17 @@ def run_must_gather(
     Returns:
         str: command output
     """
-    dest_dir = None
+    base_command = "oc adm must-gather"
     if target_base_dir:
-        dest_dir = os.path.join(
-            target_base_dir,
-            f"must_gather_{datetime.datetime.utcnow().strftime('%Y_%m_%d_%H_%M_%S')}",
-        )
-        os.makedirs(dest_dir)
+        base_command += f" --dest-dir={target_base_dir}"
+    if image_url:
+        base_command += f" --image={image_url}"
+    if skip_tls_check:
+        base_command += " --insecure-skip-tls-verify"
+    if kubeconfig:
+        base_command += f" --kubeconfig {kubeconfig}"
+    # script_name must be the last argument
+    if script_name:
+        base_command += f" -- {script_name}"
 
-    return run_command(
-        command=shlex.split(
-            must_gather_command(
-                image_url=image_url,
-                dest_dir=dest_dir,
-                kubeconfig=kubeconfig,
-                skip_tls_check=skip_tls_check,
-                script_name=script_name,
-            )
-        )
-    )[1]
+    return run_command(command=shlex.split(base_command))[1]
